#include "cassiniindexfileviewer.h"
#include "ui_cassiniindexfileviewer.h"
#include <QFileDialog>

CassiniIndexFileViewer::CassiniIndexFileViewer(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::CassiniIndexFileViewer)
{
    ui->setupUi(this);
    this->indexFile = new CassiniIndexFile();
    connect(this->ui->loadFileQpb,SIGNAL(clicked()),this,SLOT(loadFile()));
    connect(this->ui->FilteerInput,SIGNAL(textChanged(QString)),this,SLOT(filterCol(QString)));
}

CassiniIndexFileViewer::~CassiniIndexFileViewer()
{
    delete this->indexFile;
    delete ui;
}

void CassiniIndexFileViewer::filterCol(const QString &pattern)
{
    Qt::MatchFlags flag = Qt::MatchContains | Qt::MatchStartsWith	| Qt::MatchEndsWith  | Qt::MatchRegExp | Qt::MatchWildcard | Qt::MatchWrap |Qt::MatchRecursive;
    if(this->ui->FilterCaseSensitive->isChecked())
        flag |= Qt::MatchCaseSensitive;
    if(pattern.isEmpty())
    {
        for(int i=0;i<this->ui->IndexView->rowCount();i++)
            this->ui->IndexView->setRowHidden(i,false);
    }
    else
    {
        for(int i=0;i<this->ui->IndexView->rowCount();i++)
            this->ui->IndexView->setRowHidden(i,true);
        QList<QTableWidgetItem*> items = this->ui->IndexView->findItems(pattern,flag);
        for(int i=0;i<items.count();i++)
            this->ui->IndexView->setRowHidden(items.at(i)->row(),false);
    }
}

void CassiniIndexFileViewer::loadFile()
{
    QList<CassiniIndexLine> lines=this->indexFile->loadFile(QFileDialog::getOpenFileName());
    this->ui->IndexView->clear();
    this->ui->IndexView->setRowCount(lines.count());
    this->ui->IndexView->setHorizontalHeaderLabels(QStringList()<<"Dataset ID"<<"File specification name"<<"Product ID"<<"Volume ID"<<"Product Creation Time"<<"Taget name"<<"Start time"<<"Stop time");
    for(int i=0;i<lines.count();i++)
    {
        for(int j=0;j<8;j++)
        {
            QString cel=QString(lines.at(i).cels[j]).remove('\n').remove('\r');
            QTableWidgetItem *newItem = new QTableWidgetItem(cel);
            newItem->setFlags(newItem->flags() ^ Qt::ItemIsEditable);
            this->ui->IndexView->setItem(i, j, newItem);
        }
    }
}

void CassiniIndexFileViewer::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
